﻿#region Using Statements
using System;
using System.Collections;
using System.Collections.Generic;
using System.Text;
using System.Threading.Tasks;
using System.Windows;
using System.Windows.Controls;
using DomainModel;
using IdeaBlade.EntityModel;
using IdeaBlade.Core;

#endregion Using Statements

namespace FirstSilverlightApp {
  public partial class ConsoleUserControl : UserControl {
    #region ctor and startup
    public ConsoleUserControl() {
      InitializeComponent();
      Loaded += Page_Loaded;
    }

    void Page_Loaded(object sender, RoutedEventArgs e) {
      CreateEntityManager();
      DoItAsync();
    }
    #endregion ctor and startup

    #region Create EntityManager
    private void CreateEntityManager() {
      WriteMessage("Creating EntityManager.");
      _mgr = new NorthwindManager();
    }

    #endregion Create EntityManager

    #region DoItAsync
 
    // This executes a simple query.  The TraceWindow will show a "real time" display of all trace messages written by either DevForce or 
    // the application.

    private async Task DoItAsync() {
      _outputStringBuilder = new StringBuilder(
        "*** Retrieving Employees. ***\n\n");
      try {
        var employees = await _mgr.Employees.ExecuteAsync();
        this._outputTextBlock.Text = "";
        foreach (Employee anEmployee in employees) {
          _outputStringBuilder.Append(String.Format("{0}, {1}\n",
            anEmployee.LastName, anEmployee.FirstName));
        }
        ReportFetchCount(employees, "Employee");
        this._outputTextBlock.Text = _outputStringBuilder.ToString();
      } catch (Exception e) {
        WriteMessage(e.Message);
      }
      
      TraceFns.WriteLine("Hello world!");
      
    }

    #endregion 

    #region Methods to Display Status
    private void ReportFetchCount(IEnumerable result, string entityType) {
      int entitiesRetrieved = ((ICollection)result).Count;
      WriteMessage(string.Format("Retrieved {0} entities of type {1}.", entitiesRetrieved, entityType));
    }

    private void WriteMessage(string msg) {
      _msgNumber += 1;
      _statusStringBuilder.Append(String.Format("{0}", _msgNumber.ToString("D4")) +
        " " + msg + Environment.NewLine);
      _statusTextBlock.Text = _statusStringBuilder.ToString();
      _statusMsg_ScrollViewer.UpdateLayout(); // necessary here in order to get scrollbar to go to the bottom
      _statusMsg_ScrollViewer.ScrollToVerticalOffset(_statusMsg_ScrollViewer.ScrollableHeight);
      IdeaBlade.Core.TraceFns.WriteLine(msg);
    }
    #endregion Methods to Display Status

    #region Private Fields
    NorthwindManager _mgr;
    int _msgNumber = 0;
    StringBuilder _statusStringBuilder = new StringBuilder();
    StringBuilder _outputStringBuilder;
    #endregion Private Fields

  }
}
