﻿using System;
using System.Collections.ObjectModel;
using System.Windows.Controls;
using IdeaBlade.Core;

namespace FirstSilverlightApp {

  /// <summary>
  /// Sample trace subscriber.  You can drop the TraceViewer UserControl onto a page
  /// to display tracing information from the Silverlight application in a grid.
  /// </summary>
  /// <remarks>
  /// To use the TraceSubscriber: 1) listen for its Publish event, and 2) call StartSubscription()
  /// to have tracing messages sent to you.  You can also call StopSubscription()
  /// to temporarily or permanently stop receiving messages.
  /// </remarks>
  public partial class TraceWindow : UserControl {

    public TraceWindow() {

      InitializeComponent();

      _messages = new ObservableCollection<TraceMessage>();
      _subscriber = new TraceSubscriber();
      _subscriber.Publish += new EventHandler<PublishEventArgs>(_subscriber_Publish);
      _subscriber.StartSubscription();

      _dataGrid.ItemsSource = _messages;
    }

    private void _subscriber_Publish(object sender, PublishEventArgs e) {
      _messages.Add(e.TraceMessage);
      if (_dataGrid.Columns.Count > 0) {
        _dataGrid.ScrollIntoView(e.TraceMessage, _dataGrid.Columns[0]);
      }
    }

    TraceSubscriber _subscriber;
    ObservableCollection<TraceMessage> _messages;
  }
    
}