﻿#Region "Using Statements"
Imports System.Collections
Imports System.Text
Imports System.Windows
Imports System.Windows.Controls
Imports DomainModel
Imports IdeaBlade.EntityModel
Imports System.Threading.Tasks

#End Region ' Using Statements

Namespace FirstSilverlightApp
  Partial Public Class ConsoleUserControl
	  Inherits UserControl
	#Region "ctor and startup"
	Public Sub New()
	  InitializeComponent()
	  AddHandler Loaded, AddressOf Page_Loaded
	End Sub

	Private Sub Page_Loaded(ByVal sender As Object, ByVal e As RoutedEventArgs)
	  CreateEntityManager()
            DoItAsync()
        End Sub
#End Region ' ctor and startup

#Region "Create EntityManager"
        Private Sub CreateEntityManager()
            WriteMessage("Creating EntityManager.")
            _mgr = New NorthwindManager()
        End Sub

#End Region ' Create EntityManager

#Region "DoItAsync"


        ' This executes a simple query.  The TraceWindow will show a "real time" display of all trace messages written by either DevForce or 
        ' the application.

        Async Function DoItAsync() As Task
            _outputStringBuilder = New StringBuilder("*** Retrieving Employees. ***" & vbLf & vbLf)

            Try
                Dim employees = Await _mgr.Employees.ExecuteAsync()
                Me._outputTextBlock.Text = ""
                For Each anEmployee As Employee In employees
                    _outputStringBuilder.Append(String.Format("{0}, {1}" & vbLf, anEmployee.LastName, anEmployee.FirstName))
                Next anEmployee
                ReportFetchCount(employees, "Employee")
                Me._outputTextBlock.Text = _outputStringBuilder.ToString()
            Catch e As Exception
                WriteMessage(e.Message)
            End Try

            IdeaBlade.Core.TraceFns.WriteLine("Hello world!")

        End Function

#End Region

	#Region "Methods to Display Status"
	Private Sub ReportFetchCount(ByVal result As IEnumerable, ByVal entityType As String)
	  Dim entitiesRetrieved As Integer = (CType(result, ICollection)).Count
	  WriteMessage(String.Format("Retrieved {0} entities of type {1}.", entitiesRetrieved, entityType))
	End Sub

	Private Sub WriteMessage(ByVal msg As String)
	  _msgNumber += 1
	  _statusStringBuilder.Append(String.Format("{0}", _msgNumber.ToString("D4")) & " " & msg & Environment.NewLine)
	  _statusTextBlock.Text = _statusStringBuilder.ToString()
	  _statusMsg_ScrollViewer.UpdateLayout() ' necessary here in order to get scrollbar to go to the bottom
	  _statusMsg_ScrollViewer.ScrollToVerticalOffset(_statusMsg_ScrollViewer.ScrollableHeight)
	  IdeaBlade.Core.TraceFns.WriteLine(msg)
	End Sub
	#End Region ' Methods to Display Status

	#Region "Private Fields"
	Private _mgr As NorthwindManager
	Private _msgNumber As Integer = 0
	Private _statusStringBuilder As New StringBuilder()
	Private _outputStringBuilder As StringBuilder
	#End Region ' Private Fields

  End Class
End Namespace
